"use server"
import { Genre, Sub } from "@prisma/client"
import prisma from "./db"
import { revalidatePath } from "next/cache"
import { redirect } from "next/navigation"
import { subSchema } from "app/ui/forms/schemas"


export async function updateField({ datum, table, column, id, pathname }: { datum?: string | number | Genre[], table: string, column: string, id: number, pathname: string }) {
	"use server"
	try {
		const res = await prisma[table].update({
			where: { id },
			data: {
				[column]: datum
			}
		})
		console.log(`updated record in ${table}: ${JSON.stringify(res)}`)
		revalidatePath(pathname)
		return res
	} catch (error) {
		console.error(error)
		return undefined
	}
}

export async function updateGenres({ genres, table, id, pathname }: { genres: { id: number }[], table: string, id: number, pathname: string }) {
	"use server"
	try {
		const res = await prisma[table].update({
			where: { id },
			data: {
				genres: { set: genres }
			}
		})
		console.log(`updated record in ${table}: ${JSON.stringify(res)}`)
		revalidatePath(pathname)
		return res
	} catch (error) {
		console.error(error)
		return undefined
	}
}

export async function updateSub(data: Sub): Promise<Sub | undefined> {
	"use server"
	try {
		subSchema.parse(data)
		const res = await prisma.sub.update({ where: { id: data.id }, data })
		revalidatePath("submission")
		return res
	} catch (error) {
		console.error(error)
		return undefined
	}
}








